@@ -25,7 +25,7 @@ class HookService(RetrieveMixin, UpdateMixin):
 
     def verify(self,
                key: int = None):
-        return self._post(f'{self.api_url}/{key}')
+        return self._post(f'{self.api_url}/{key}/verify')
 
     def list_event_keys(self):
         return self._get(f"{self.api_url}/event_keys")
