@@ -14,4 +14,4 @@ class EmailService(BaseService):
         return self.call("optOut", email, reason)
 
     def optin_email(self, email, reason):
-        return self.call("optIn", email)
+        return self.call("optIn", email, reason)
